from setuptools import setup

setup(
    name='r-styler',
    version="1.0.0",
    description='r-styler - listed by Cycode to prevent confusion',
    long_description="r-styler",
    long_description_content_type='text/markdown',
)
